==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/wafv2_rule_group/Wafv2RuleGroupRuleActionOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.wafv2_rule_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:56.125Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.wafv2RuleGroup.Wafv2RuleGroupRuleActionOutputReference")
public class Wafv2RuleGroupRuleActionOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected Wafv2RuleGroupRuleActionOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Wafv2RuleGroupRuleActionOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Wafv2RuleGroupRuleActionOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putAllow(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllow value) {
        software.amazon.jsii.Kernel.call(this, "putAllow", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putBlock(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlock value) {
        software.amazon.jsii.Kernel.call(this, "putBlock", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCount(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCount value) {
        software.amazon.jsii.Kernel.call(this, "putCount", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetAllow() {
        software.amazon.jsii.Kernel.call(this, "resetAllow", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetBlock() {
        software.amazon.jsii.Kernel.call(this, "resetBlock", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCount() {
        software.amazon.jsii.Kernel.call(this, "resetCount", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllowOutputReference getAllow() {
        return software.amazon.jsii.Kernel.get(this, "allow", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllowOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlockOutputReference getBlock() {
        return software.amazon.jsii.Kernel.get(this, "block", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlockOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCountOutputReference getCount() {
        return software.amazon.jsii.Kernel.get(this, "count", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCountOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllow getAllowInput() {
        return software.amazon.jsii.Kernel.get(this, "allowInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllow.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlock getBlockInput() {
        return software.amazon.jsii.Kernel.get(this, "blockInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlock.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCount getCountInput() {
        return software.amazon.jsii.Kernel.get(this, "countInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCount.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleAction getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleAction.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleAction value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/wafv2_rule_group/Wafv2RuleGroupRuleActionOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.wafv2_rule_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:12.203Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.wafv2RuleGroup.Wafv2RuleGroupRuleActionOutputReference")
public class Wafv2RuleGroupRuleActionOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected Wafv2RuleGroupRuleActionOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Wafv2RuleGroupRuleActionOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Wafv2RuleGroupRuleActionOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putAllow(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllow value) {
        software.amazon.jsii.Kernel.call(this, "putAllow", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putBlock(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlock value) {
        software.amazon.jsii.Kernel.call(this, "putBlock", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCaptcha(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCaptcha value) {
        software.amazon.jsii.Kernel.call(this, "putCaptcha", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putChallenge(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionChallenge value) {
        software.amazon.jsii.Kernel.call(this, "putChallenge", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCount(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCount value) {
        software.amazon.jsii.Kernel.call(this, "putCount", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetAllow() {
        software.amazon.jsii.Kernel.call(this, "resetAllow", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetBlock() {
        software.amazon.jsii.Kernel.call(this, "resetBlock", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCaptcha() {
        software.amazon.jsii.Kernel.call(this, "resetCaptcha", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetChallenge() {
        software.amazon.jsii.Kernel.call(this, "resetChallenge", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCount() {
        software.amazon.jsii.Kernel.call(this, "resetCount", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllowOutputReference getAllow() {
        return software.amazon.jsii.Kernel.get(this, "allow", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllowOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlockOutputReference getBlock() {
        return software.amazon.jsii.Kernel.get(this, "block", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlockOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCaptchaOutputReference getCaptcha() {
        return software.amazon.jsii.Kernel.get(this, "captcha", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCaptchaOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionChallengeOutputReference getChallenge() {
        return software.amazon.jsii.Kernel.get(this, "challenge", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionChallengeOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCountOutputReference getCount() {
        return software.amazon.jsii.Kernel.get(this, "count", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCountOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllow getAllowInput() {
        return software.amazon.jsii.Kernel.get(this, "allowInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionAllow.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlock getBlockInput() {
        return software.amazon.jsii.Kernel.get(this, "blockInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionBlock.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCaptcha getCaptchaInput() {
        return software.amazon.jsii.Kernel.get(this, "captchaInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCaptcha.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionChallenge getChallengeInput() {
        return software.amazon.jsii.Kernel.get(this, "challengeInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionChallenge.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCount getCountInput() {
        return software.amazon.jsii.Kernel.get(this, "countInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleActionCount.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleAction getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleAction.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_rule_group.Wafv2RuleGroupRuleAction value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
